@@ -1,10 +1,10 @@
 ##----------------------------------------------------------------------------
 ## Getopt::Long with Class - ~/lib/Getopt/Class.pm
-## Version 0.2.0
+## Version 0.1
 ## Copyright(c) 2020 DEGUEST Pte. Ltd.
 ## Author: Jacques Deguest <jack@deguest.jp>
 ## Created 2020/04/25
-## Modified 2020/04/27
+## Modified 2020/04/26
 ## All rights reserved
 ## 
 ## This program is free software; you can redistribute  it  and/or  modify  it
@@ -21,7 +21,7 @@ BEGIN
     use DateTime;
     use DateTime::Format::Strptime;
     use Scalar::Util;
-    our $VERSION = '0.002000';
+    our $VERSION = '0.1';
 };
 
 sub init
@@ -149,7 +149,7 @@ sub check_class_data
         my $def = $dict->{ $f };
         my $n = $def->{name} ? $def->{name} : $f;
         $def->{error} ||= "does not match requirements";
-        if( $def->{required} )
+        if( !!$p->{required} && $def->{required} )
         {
             if( ( $def->{type} =~ /^(?:boolean|decimal|integer|string)/ && !length( $v->{ $f } ) ) || 
                 ( ( $def->{type} eq 'hash' || $def->{type} eq 'string-hash' ) && !scalar( keys( %{$v->{ $f }} ) ) ) ||
@@ -432,7 +432,7 @@ sub exec
                     return( $self->error( "An unexpected error occurred while converting date provided for \"$k\" (", $v->{ $k }, "): $e" ) );
                 }
             }
-            elsif( $opts->{ $k } eq 'now' || $opts->{ $k } eq 'today' )
+            elsif( $opts->{ $k } eq 'now' )
             {
                 my $dt = DateTime->now( time_zone => 'local' );
                 $opts->{ $k2_dash } = $dt;
@@ -440,7 +440,7 @@ sub exec
             }
             else
             {
-                return( $self->error( "Unsuported value for date or datetime \"$k\": ", $v->{ $k }, ". Please use a unix timestamp (i.e. an integer) or an iso 8601 type like 2019-12-25 or 2019-12-25T07:30:10" ) );
+                return( $self->error( "Unsuported value for date or datetime \"$f\": ", $v->{ $k }, ". Please use a unix timestamp (i.e. an integer) or an iso 8601 type like 2019-12-25" ) );
             }
             ## Default format for stringification is the unix timestamp
             my $fmt = DateTime::Format::Strptime->new(
@@ -564,7 +564,7 @@ Getopt::Class - Extended dictionary version of Getopt::Long
 
 =head1 VERSION
 
-    v0.2.0
+    v0.1
 
 =head1 DESCRIPTION
 
@@ -731,7 +731,7 @@ The array reference is a L<Module::Generic::Array> object.
 
 =head2 configure
 
-This calls L<Getopt::Long/"configure"> with the L</"configure_options">.
+This calls L<Getopt::Long::configure> with the L</"configure_options">.
 
 It can be overriden by calling L</"configure"> with an array reference.
 
@@ -876,7 +876,7 @@ Jacques Deguest E<lt>F<jack@deguest.jp>E<gt>
 
 =head1 SEE ALSO
 
-L<Getopt::Longs>
+L<Net::API::Stripe::Number::Format>
 
 =head1 COPYRIGHT & LICENSE
 
